@@ -882,55 +882,55 @@ PALETTES = {
         '#363636363636:#FFFF08088383:#8383FFFF0808:#FFFF83830808:#08088383FFFF:'
         '#83830808FFFF:#0808FFFF8383:#B6B6B6B6B6B6:#424242424242:#FFFF1E1E8E8E:'
         '#8E8EFFFF1E1E:#FFFF8E8E1E1E:#1E1E8E8EFFFF:#8E8E1E1EFFFF:#1E1EFFFF8E8E:'
-        '#C2C2C2C2C2C2:#0D0D19192626:#B4B4E1E1FDFD'
+        '#C2C2C2C2C2C2:#B4B4E1E1FDFD:#0D0D19192626'
     ),
     'Aco': (
         '#3F3F3F3F3F3F:#FFFF08088383:#8383FFFF0808:#FFFF83830808:#08088383FFFF:'
         '#83830808FFFF:#0808FFFF8383:#BEBEBEBEBEBE:#474747474747:#FFFF1E1E8E8E:'
         '#8E8EFFFF1E1E:#FFFF8E8E1E1E:#1E1E8E8EFFFF:#8E8E1E1EFFFF:#1E1EFFFF8E8E:'
-        '#C4C4C4C4C4C4:#1F1F13130505:#B4B4E1E1FDFD'
+        '#C4C4C4C4C4C4:#B4B4E1E1FDFD:#1F1F13130505'
     ),
     'Azu': (
         '#000000000000:#ACAC6D6D7474:#7474ACAC6D6D:#ACACA4A46D6D:#6D6D7474ACAC:'
         '#A4A46D6DACAC:#6D6DACACA4A4:#E6E6E6E6E6E6:#262626262626:#D6D6B8B8BCBC:'
         '#BCBCD6D6B8B8:#D6D6D3D3B8B8:#B8B8BCBCD6D6:#D3D3B8B8D6D6:#B8B8D6D6D3D3:'
-        '#FFFFFFFFFFFF:#090911111A1A:#D9D9E6E6F2F2'
+        '#FFFFFFFFFFFF:#D9D9E6E6F2F2:#090911111A1A'
     ),
     'Bim': (
         '#2C2C24242323:#F5F55757A0A0:#A9A9EEEE5555:#F5F5A2A25555:#5E5EA2A2ECEC:'
         '#A9A95757ECEC:#5E5EEEEEA0A0:#919189898888:#919189898888:#F5F57979B2B2:'
         '#BBBBEEEE7878:#F5F5B3B37878:#8181B3B3ECEC:#BBBB7979ECEC:#8181EEEEB2B2:'
-        '#F5F5EEEEECEC:#010128284949:#A9A9BEBED8D8'
+        '#F5F5EEEEECEC:#A9A9BEBED8D8:#010128284949'
     ),
     'Cai': (
         '#000000000000:#CACA27274D4D:#4D4DCACA2727:#CACAA4A42727:#27274D4DCACA:'
         '#A4A42727CACA:#2727CACAA4A4:#808080808080:#808080808080:#E9E98D8DA3A3:'
         '#A3A3E9E98D8D:#E9E9D4D48D8D:#8D8DA3A3E9E9:#D4D48D8DE9E9:#8D8DE9E9D4D4:'
-        '#FFFFFFFFFFFF:#090911111A1A:#D9D9E6E6F2F2'
+        '#FFFFFFFFFFFF:#D9D9E6E6F2F2:#090911111A1A'
     ),
     'Elementary': (
         '#303030303030:#E1E132321A1A:#6A6AB0B01717:#FFFFC0C00505:#00004F4F9E9E:'
         '#ECEC00004848:#2A2AA7A7E7E7:#F2F2F2F2F2F2:#5D5D5D5D5D5D:#FFFF36361E1E:'
         '#7B7BC9C91F1F:#FFFFD0D00A0A:#00007171FFFF:#FFFF1D1D6262:#4B4BB8B8FDFD:'
-        '#A0A02020F0F0:#101010101010:#F2F2F2F2F2F2'
+        '#A0A02020F0F0:#F2F2F2F2F2F2:#101010101010'
     ),
     'Elic': (
         '#303030303030:#E1E132321A1A:#6A6AB0B01717:#FFFFC0C00505:#72729F9FCFCF:'
         '#ECEC00004848:#F2F2F2F2F2F2:#2A2AA7A7E7E7:#5D5D5D5D5D5D:#FFFF36361E1E:'
         '#7B7BC9C91F1F:#FFFFD0D00A0A:#00007171FFFF:#FFFF1D1D6262:#4B4BB8B8FDFD:'
-        '#A0A02020F0F0:#4A4A45453E3E:#F2F2F2F2F2F2'
+        '#A0A02020F0F0:#F2F2F2F2F2F2:#4A4A45453E3E'
     ),
     'Elio': (
         '#303030303030:#E1E132321A1A:#6A6AB0B01717:#FFFFC0C00505:#72729F9FCFCF:'
         '#ECEC00004848:#2A2AA7A7E7E7:#F2F2F2F2F2F2:#5D5D5D5D5D5D:#FFFF36361E1E:'
         '#7B7BC9C91F1F:#FFFFD0D00A0A:#00007171FFFF:#FFFF1D1D6262:#4B4BB8B8FDFD:'
-        '#A0A02020F0F0:#04041A1A3B3B:#F2F2F2F2F2F2'
+        '#A0A02020F0F0:#F2F2F2F2F2F2:#04041A1A3B3B'
     ),
     'Freya': (
         '#070736364242:#DCDC32322F2F:#858599990000:#B5B589890000:#26268B8BD2D2:'
         '#ECEC00004848:#2A2AA1A19898:#9494A3A3A5A5:#58586E6E7575:#CBCB4B4B1616:'
         '#858599990000:#B5B589890000:#26268B8BD2D2:#D3D336368282:#2A2AA1A19898:'
-        '#6C6C7171C4C4:#25252E2E3232:#9494A3A3A5A5'
+        '#6C6C7171C4C4:#9494A3A3A5A5:#25252E2E3232'
     ),
     'Gruvbox Dark': (
         '#66665C5C5454:#FBFB49493434:#8383A5A59898:#D7D799992121:#B1B162628686:'
@@ -942,96 +942,96 @@ PALETTES = {
         '#444444444444:#FFFF00005454:#B1B1D6D63030:#9D9D89895E5E:#6767BEBEE3E3:'
         '#B5B57676BCBC:#56569A9A9F9F:#EDEDEDEDEDED:#777777777777:#D6D65E5E7575:'
         '#BABAFFFFAAAA:#ECECE1E1C8C8:#9F9FD3D3E5E5:#DEDEB3B3DFDF:#B6B6E0E0E5E5:'
-        '#FFFFFFFFFFFF:#000000000000:#FFFFFFFFFFFF'
+        '#FFFFFFFFFFFF:#FFFFFFFFFFFF:#000000000000'
     ),
     'Hemisu Light': (
         '#777777777777:#FFFF00005555:#737391910000:#50503D3D1515:#535380809191:'
         '#5B5B34345E5E:#535380809191:#999999999999:#999999999999:#D6D65E5E7676:'
         '#9C9CC7C70000:#949475755555:#9D9DB3B3CDCD:#A1A18484A4A4:#8585B2B2AAAA:'
-        '#BABABABABABA:#EFEFEFEFEFEF:#444444444444'
+        '#BABABABABABA:#444444444444:#EFEFEFEFEFEF'
     ),
     'Jup': (
         '#000000000000:#DDDD00006F6F:#6F6FDDDD0000:#DDDD6F6F0000:#00006F6FDDDD:'
         '#6F6F0000DDDD:#0000DDDD6F6F:#F2F2F2F2F2F2:#7D7D7D7D7D7D:#FFFF7474B9B9:'
         '#B9B9FFFF7474:#FFFFB9B97474:#7474B9B9FFFF:#B9B97474FFFF:#7474FFFFB9B9:'
-        '#FFFFFFFFFFFF:#757584848080:#232347476A6A'
+        '#FFFFFFFFFFFF:#232347476A6A:#757584848080'
     ),
     'Mar': (
         '#000000000000:#B5B540407B7B:#7B7BB5B54040:#B5B57B7B4040:#40407B7BB5B5:'
         '#7B7B4040B5B5:#4040B5B57B7B:#F8F8F8F8F8F8:#737373737373:#CDCD7373A0A0:'
         '#A0A0CDCD7373:#CDCDA0A07373:#7373A0A0CDCD:#A0A07373CDCD:#7373CDCDA0A0:'
-        '#FFFFFFFFFFFF:#FFFFFFFFFFFF:#232347476A6A'
+        '#FFFFFFFFFFFF:#232347476A6A:#FFFFFFFFFFFF'
     ),
     'Material': (
         '#070736364141:#EBEB60606B6B:#C3C3E8E88D8D:#F7F7EBEB9595:#8080CBCBC3C3:'
         '#FFFF24249090:#AEAEDDDDFFFF:#FFFFFFFFFFFF:#00002B2B3636:#EBEB60606B6B:'
         '#C3C3E8E88D8D:#F7F7EBEB9595:#7D7DC6C6BFBF:#6C6C7171C3C3:#343443434D4D:'
-        '#FFFFFFFFFFFF:#1E1E28282C2C:#C3C3C7C7D1D1'
+        '#FFFFFFFFFFFF:#C3C3C7C7D1D1:#1E1E28282C2C'
     ),
     'Miu': (
         '#000000000000:#B8B87A7A7A7A:#7A7AB8B87A7A:#B8B8B8B87A7A:#7A7A7A7AB8B8:'
         '#B8B87A7AB8B8:#7A7AB8B8B8B8:#D9D9D9D9D9D9:#262626262626:#DBDBBDBDBDBD:'
         '#BDBDDBDBBDBD:#DBDBDBDBBDBD:#BDBDBDBDDBDB:#DBDBBDBDDBDB:#BDBDDBDBDBDB:'
-        '#FFFFFFFFFFFF:#0D0D19192626:#D9D9E6E6F2F2'
+        '#FFFFFFFFFFFF:#D9D9E6E6F2F2:#0D0D19192626'
     ),
     'Monokai dark': (
         '#757571715E5E:#F9F926267272:#A6A6E2E22E2E:#F4F4BFBF7575:#6666D9D9EFEF:'
         '#AEAE8181FFFF:#2A2AA1A19898:#F9F9F8F8F5F5:#272728282222:#F9F926267272:'
         '#A6A6E2E22E2E:#F4F4BFBF7575:#6666D9D9EFEF:#AEAE8181FFFF:#2A2AA1A19898:'
-        '#F8F8F8F8F2F2:#272728282222:#F8F8F8F8F2F2'
+        '#F8F8F8F8F2F2:#F8F8F8F8F2F2:#272728282222'
     ),
     'Nep': (
         '#000000000000:#DDDD6F6F0000:#0000DDDD6F6F:#6F6FDDDD0000:#6F6F0000DDDD:'
         '#DDDD00006F6F:#00006F6FDDDD:#F2F2F2F2F2F2:#7D7D7D7D7D7D:#FFFFB9B97474:'
         '#7474FFFFB9B9:#B9B9FFFF7474:#B9B97474FFFF:#FFFF7474B9B9:#7474B9B9FFFF:'
-        '#FFFFFFFFFFFF:#757584848080:#232347476A6A'
+        '#FFFFFFFFFFFF:#232347476A6A:#757584848080'
     ),
     'One Light': (
         '#000000000000:#DADA3E3E3939:#414193933E3E:#858555550404:#31315E5EEEEE:'
         '#939300009292:#0E0E6F6FADAD:#8E8E8F8F9696:#2A2A2B2B3232:#DADA3E3E3939:'
         '#414193933E3E:#858555550404:#31315E5EEEEE:#939300009292:#0E0E6F6FADAD:'
-        '#FFFFFEFEFEFE:#F8F8F8F8F8F8:#2A2A2B2B3232'
+        '#FFFFFEFEFEFE:#2A2A2B2B3232:#F8F8F8F8F8F8'
     ),
     'Pali': (
         '#0A0A0A0A0A0A:#ABAB8F8F7474:#7474ABAB8F8F:#8F8FABAB7474:#8F8F7474ABAB:'
         '#ABAB74748F8F:#74748F8FABAB:#F2F2F2F2F2F2:#5D5D5D5D5D5D:#FFFF1D1D6262:'
         '#9C9CC3C3AFAF:#FFFFD0D00A0A:#AFAF9C9CC3C3:#FFFF1D1D6262:#4B4BB8B8FDFD:'
-        '#A0A02020F0F0:#23232E2E3737:#D9D9E6E6F2F2'
+        '#A0A02020F0F0:#D9D9E6E6F2F2:#23232E2E3737'
     ),
     'Peppermint': (
         '#353535353535:#E6E645456969:#8989D2D28787:#DADAB7B75252:#43439E9ECFCF:'
         '#D9D96161DCDC:#6464AAAAAFAF:#B3B3B3B3B3B3:#535353535353:#E4E485859A9A:'
         '#A2A2CCCCA1A1:#E1E1E3E38787:#6F6FBBBBE2E2:#E5E58686E7E7:#9696DCDCDADA:'
-        '#DEDEDEDEDEDE:#000000000000:#C7C7C7C7C7C7'
+        '#DEDEDEDEDEDE:#C7C7C7C7C7C7:#000000000000'
     ),
     'Sat': (
         '#000000000000:#DDDD00000707:#0707DDDD0000:#DDDDD6D60000:#00000707DDDD:'
         '#D6D60000DDDD:#0000DDDDD6D6:#F2F2F2F2F2F2:#7D7D7D7D7D7D:#FFFF74747878:'
         '#7878FFFF7474:#FFFFFAFA7474:#74747878FFFF:#FAFA7474FFFF:#7474FFFFFAFA:'
-        '#FFFFFFFFFFFF:#757584848080:#232347476A6A'
+        '#FFFFFFFFFFFF:#232347476A6A:#757584848080'
     ),
     'Shel': (
         '#2C2C24242323:#ABAB24246363:#6C6CA3A32323:#ABAB64642323:#2C2C6464A2A2:'
         '#6C6C2424A2A2:#2C2CA3A36363:#919189898888:#919189898888:#F5F58888B9B9:'
         '#C2C2EEEE8686:#F5F5BABA8686:#8F8FBABAECEC:#C2C28888ECEC:#8F8FEEEEB9B9:'
-        '#F5F5EEEEECEC:#2A2A20201F1F:#48488282CDCD'
+        '#F5F5EEEEECEC:#48488282CDCD:#2A2A20201F1F'
     ),
     'Tin': (
         '#000000000000:#8D8D53534E4E:#4E4E8D8D5353:#88888D8D4E4E:#53534E4E8D8D:'
         '#8D8D4E4E8888:#4E4E88888D8D:#FFFFFFFFFFFF:#000000000000:#B5B57D7D7878:'
         '#7878B5B57D7D:#B0B0B5B57878:#7D7D7878B5B5:#B5B57878B0B0:#7878B0B0B5B5:'
-        '#FFFFFFFFFFFF:#2E2E2E2E3535:#FFFFFFFFFFFF'
+        '#FFFFFFFFFFFF:#FFFFFFFFFFFF:#2E2E2E2E3535'
     ),
     'Ura': (
         '#000000000000:#C2C21B1B6F6F:#6F6FC2C21B1B:#C2C26F6F1B1B:#1B1B6F6FC2C2:'
         '#6F6F1B1BC2C2:#1B1BC2C26F6F:#808080808080:#808080808080:#EEEE8484B9B9:'
         '#B9B9EEEE8484:#EEEEB9B98484:#8484B9B9EEEE:#B9B98484EEEE:#8484EEEEB9B9:'
-        '#E5E5E5E5E5E5:#FEFEFFFFEEEE:#232347476A6A'
+        '#E5E5E5E5E5E5:#232347476A6A:#FEFEFFFFEEEE'
     ),
     'Vag': (
         '#303030303030:#A8A871713939:#3939A8A87171:#7171A8A83939:#71713939A8A8:'
         '#A8A839397171:#39397171A8A8:#8A8A8A8A8A8A:#494949494949:#B0B076763B3B:'
         '#3B3BB0B07676:#7676B0B03B3B:#76763B3BB0B0:#B0B03B3B7676:#3B3B7676B0B0:'
-        '#CFCFCFCFCFCF:#19191F1F1D1D:#D9D9E6E6F2F2'
+        '#CFCFCFCFCFCF:#D9D9E6E6F2F2:#19191F1F1D1D'
     ),
 }
