@@ -88,7 +88,7 @@ class SimpleGladeApp():
     def __repr__(self):
         class_name = self.__class__.__name__
         if self.main_widget:
-            root = gtk.Widget.get_name(self.main_widget)
+            root = Gtk.Widget.get_name(self.main_widget)
             repr = '%s(path="%s", root="%s")' % (class_name, self.glade_path, root)
         else:
             repr = '%s(path="%s")' % (class_name, self.glade_path)
